<?php 
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */
/*
 * Copyright 2004-2007 Project Guarana Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/**
 * @package ficus.db
 */
/**
 * @file S2DaoManager.php
 * @brief s2dao manager
 * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
 * @version $Id: S2DaoManager.php 33 2007-08-19 18:00:31Z ishitoya $
 */

require_once("ficus/config/Registry.php");

/**
 * @class S2DaoManager
 */
class Ficus_S2DaoManager{
    /**
     * dao object
     */
    protected $dao = null;

    /**
     * pdo object
     */
    protected $pdo = null;

    /**
     * construct
     */
    public function __construct($target = null){
        if(is_null($target) == false){
            $this->setTarget($target);
        }
    }            
    
    /**
     * set dao
     * @param $target string target entity name
     */
    public function setTarget($target){
        $pdo = Ficus_S2DaoComponentFactory::getComponent("dataSource");
        $this->pdo = new Ficus_PDODatabase($pdo->getConnection());
        $this->dao =
            Ficus_S2DaoComponentFactory::getModelFactory()->getDao($target);
        return $this;
    }
    
    /**
     * get Entity
     * @param $id id
     */
    public function getSingleEntity($id){
        if($id instanceof Ficus_S2DaoDataTransferObject){
            $entity = $this->dao->getWithCondition($id);
        }else{
            $entity = $this->dao->getById($id);
        }
        if($entity->isEmpty()){
            return null;
        }
        return $entity->get(0);
    }

    /**
     * get Entities
     * @param $ids array id list
     * @return S2Dao_ArrayList 
     */
    public function getEntities($ids){
        if(is_array($ids) == false){
            throw new Ficus_IllegalArgumentException("no id specified");
        }
        $entities = new S2Dao_ArrayList();
        foreach($ids as $id){
            if(is_int($id)){
                $entities->append($this->getSingleEntity($id));
            }
        }
        if($entities->isEmpty()){
            throw new Ficus_IllegalArgumentException("no entities related with ids");
        }
        return $entities;
    }

    /**
     * get Pager entities
     */
    public function getPagerDto($offset = 0, $limit = 10){ 
        $dto = $this->dao->dto();
        $dto->setOffset($offset);
        $dto->setLimit($limit);

        return $dto;
    }

    /**
     * deserializeEntity
     */
    public function deserializeEntity($data){
        $entity = $this->dao->entity();
        $deserializer = new Ficus_S2DaoArrayEntityDeserializer();
        $entity->deserialize($data, $deserializer);

        return $entity;
    }

    /**
     * get dao
     */
    public function dao(){
        return $this->dao;
    }

    /**
     * get dto
     */
    public function dto(){
        return $this->dao->dto();
    }

    /**
     * entity
     */
    public function entity(){
        return $this->dao->entity();
    }

    /**
     * get pdo
     */
    public function pdo(){
        return $this->pdo;
    }
}
?>
