<?php 
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */
/*
 * Copyright 2004-2007 Project Guarana Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/**
 * @package ficus.pages.scaffold.builder
 */
/**
 * @file AbstractScaffoldBuilder.php
 * @brief AbstractScaffoldBuilder.
 * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
 * @version $Id: ConcreteScaffoldBuilder.php 48 2007-09-20 07:21:07Z ishitoya $
 *
 */

require_once("ficus/lang/Assert.php");

/**
 * @class Ficus_AbstractScaffoldBuilder
 */
class Ficus_ConcreteScaffoldBuilder
implements Ficus_ScaffoldBuilder, Ficus_ScaffoldConstants{
    /**
     * mediator
     */
    protected $mediator = null;


    /**
     * constructor
     * @param $mediator Ficus_ScaffoldMediator mediator
     */
    public function __construct($mediator){
        $this->mediator = $mediator;
    }
    
    /**
     * build interface from entity
     * @param $entity Ficus_S2DaoEntity entity
     */
    public function build($entity){
        if($entity instanceof S2Dao_ArrayList){
            foreach($entity as $target){
                $this->mediator->scaffold()->add(
                                        $this->createScaffold($target));
            }
        }else{
            $scaffold = $this->createScaffold($entity);
            $this->mediator->scaffold()->setEntities($scaffold->entities());
        }
    }

    /**
     * create container
     * @param $parts array of parts
     * @return Ficus_ConcreateScaffoldPartsContainer
     */
    protected function createScaffold($entity){
        Ficus_Assert::isInstanceOf($entity, "Ficus_S2DaoEntity");
        $scaffold = new Ficus_Scaffold();
        $scaffold->setConfig($this->mediator->scaffold()->config());

        $entities = $this->buildEntities($entity);
        foreach($entities as $entity){
            $scaffold->add($entity);
        }
        return $scaffold;
    }
    
    /**
     * build parts array
     * @param $entity Ficus_S2DaoEntity target entity
     * @return array of parts
     */
    protected function buildEntities($entity, $parent = null){
        $entity->fetch();
        $reader = new Ficus_S2DaoEntityAnnotationReader($entity);

        $config = $this->mediator->table($entity->getEntityName());

        $settings = $config->properties();
        $reader->sort($settings);
           
        $parts = array();
        $properties = $reader->properties();
        foreach($properties as $property){
            $value = $entity->get($property);
            $part = $this->buildEntity($reader, $property, $value, $parent);
            $parts[$property] = $part;
        }
        return $parts;
    }


    /**
     * build part
     * @param $reader Ficus_S2DaoEntityAnnotationReader reader
     * @param $property string property name
     * @param $value mixed value
     * @return Ficus_ScaffoldPart part
     */
    protected function buildEntity($reader, $property, $value, $parent = null){
        $type = $reader->type($property);
        $label = $reader->label($property);
        $remark = $reader->remark($property);
        $datatype = $reader->datatype($property);
        $entity = new Ficus_ScaffoldEntity();
        
        $entity->setEntity($reader->getTarget());
        $entity->setName($property);
        $entity->setType($type);
        $entity->setLabel($label);
        $entity->setRemark($remark);
        $entity->setParent($parent);

        if($value instanceof Ficus_S2DaoEntity){
            $entities = $this->buildEntities($value, $entity);
            $entity->setParts($entities);
        }
        $entity->setValue($value);
        $entity->initialize();
        return $entity;
    }
}
?>